import { formatImgUrl } from "@/common/fotmat";
import Preview from "@/pages/details/components/preview";
import { Image, View } from "@tarojs/components";
import { memo, useMemo, useState } from "react";
import styles from './index.module.scss'
import Taro from "@tarojs/taro";

//该组件宽高为100%需调整外层元素宽高
type Param = {
    value?: { 
        texture_url?: string, //纹理图路径
        lab?: {l:number, a:number, b:number}, //lab
        rgb?: {r:number, g:number, b:number} //rgb
    },
    checkStatus: false|true
}
export default memo(({value, checkStatus = false}:Param) => {
    //lab是否都是0
    const rgbStyle = useMemo(() => {
        if(value?.lab&&(value.lab.l||value.lab.a||value.lab.b)) {
            return {'backgroundColor':`rgb(${value.rgb?.r} ${value.rgb?.g} ${value.rgb?.b})`}
        } else {
            return null
        }
    }, [value])

    const [showPreview, setShowPreview] = useState(false)
    const onClickShow = () => {
        setShowPreview(() => true)
    }

    const onShowImage = () => {
        if(!checkStatus) return false
        Taro.previewImage({
            current: formatImgUrl(value?.texture_url, '!w800'), // 当前显示
            urls: [formatImgUrl(value?.texture_url, '!w800')]  // 需要预览的图片http链接列表
        })
    }

    return (
        <>
            <View className={styles.labAndImg_main}>
                {value?.texture_url&&<Image mode="aspectFill" onClick={() => onShowImage()} src={formatImgUrl(value?.texture_url)}></Image>}
                {(!value?.texture_url&&rgbStyle)&&<View className={styles.boxColor} onClick={() => onClickShow()} style={{...rgbStyle}}></View>}
                {(!value?.texture_url&&!rgbStyle)&&<Image mode="aspectFill" src={formatImgUrl('')}></Image>}
            </View>
            <Preview value={rgbStyle} show={showPreview} onClose={() => setShowPreview(false)}/>
        </>
    )
})